@@ -30,12 +30,14 @@ class RunDatabasesIdentifier:
         optimization_campaign_name=None,
         database_adaptor=adaptors.TinyDBAdaptor,
         backtesting_id=None,
+        live_id=None,
         optimizer_id=None,
         context=None,
     ):
         self.database_adaptor = database_adaptor
         self.optimization_campaign_name = optimization_campaign_name
         self.backtesting_id = backtesting_id
+        self.live_id = live_id
         self.optimizer_id = optimizer_id
         self.tentacle_class = tentacle_class
         self.context = context
@@ -121,7 +123,15 @@ class RunDatabasesIdentifier:
         :return: the database identifier associated to backtesting metadata
         """
         return self._get_db_identifier(
-            f"{enums.RunDatabases.METADATA.value}", None, ignore_backtesting_id=True
+            enums.RunDatabases.METADATA.value, None, ignore_backtesting_id=True
+        )
+
+    def get_bot_live_metadata_identifier(self) -> str:
+        """
+        :return: the database identifier associated to live metadata
+        """
+        return self._get_db_identifier(
+            enums.RunDatabases.METADATA.value, None, ignore_live_id=True
         )
 
     def _get_db_identifier(self, run_database_name, exchange, **base_folder_kwargs):
@@ -195,6 +205,12 @@ class RunDatabasesIdentifier:
         """
         return await self._generate_new_id(is_optimizer=False)
 
+    async def generate_new_bot_live_id(self) -> int:
+        """
+        :return: a new unique bot recording id
+        """
+        return await self._generate_new_id(is_optimizer=False, is_bot_recording=True)
+
     async def generate_new_optimizer_id(self, back_list) -> int:
         """
         :return: a new unique optimizer id
@@ -212,7 +228,9 @@ class RunDatabasesIdentifier:
             return
         raise RuntimeError(f"Unhandled database_adaptor {self.database_adaptor}")
 
-    async def _generate_new_id(self, back_list=None, is_optimizer=False):
+    async def _generate_new_id(
+        self, back_list=None, is_optimizer=False, is_bot_recording=False
+    ):
         back_list = back_list or []
         max_runs = (
             constants.MAX_OPTIMIZER_RUNS
@@ -225,7 +243,11 @@ class RunDatabasesIdentifier:
             name_candidate = (
                 self._base_folder(optimizer_id=index)
                 if is_optimizer
-                else self._base_folder(backtesting_id=index)
+                else (
+                    self._base_folder(live_id=index)
+                    if is_bot_recording
+                    else self._base_folder(backtesting_id=index)
+                )
             )
             if not await self.database_adaptor.identifier_exists(name_candidate, False):
                 return index
@@ -280,6 +302,8 @@ class RunDatabasesIdentifier:
         self,
         ignore_backtesting_id=False,
         backtesting_id=None,
+        live_id=None,
+        ignore_live_id=None,
         ignore_optimizer_id=False,
         optimizer_id=None,
         from_global_history=False,
@@ -287,6 +311,7 @@ class RunDatabasesIdentifier:
         path = self._get_base_path(from_global_history, backtesting_id, optimizer_id)
         backtesting_id = backtesting_id or self.backtesting_id
         optimizer_id = optimizer_id or self.optimizer_id
+        live_id = live_id or self.live_id
         # when in optimizer or backtesting: wrap it into the current campaign
         if backtesting_id is not None or optimizer_id is not None:
             if self.optimization_campaign_name is None:
@@ -316,7 +341,13 @@ class RunDatabasesIdentifier:
             )
         if optimizer_id is None:
             # live mode
-            return self._merge_parts(path, enums.RunDatabases.LIVE.value)
+            if ignore_live_id:
+                return self._merge_parts(path, enums.RunDatabases.LIVE.value)
+            return self._merge_parts(
+                path,
+                f"{os.path.join(enums.RunDatabases.LIVE.value, enums.RunDatabases.LIVE.value)}"
+                f"{constants.DB_SEPARATOR}{live_id}",
+            )
         return path
 
     def _merge_parts(self, *parts):
